@@ -1,4 +1,4 @@
 #include "version.h"
 char PROGRAM_TITLE[] = "DsTool";
 char VERSION[] = "DsTool for linux, Version Tk";
-char BUILD_INFO[] = "Built by lapeyre@, Thu Dec  3 02:35:04 MST 1998";
+char BUILD_INFO[] = "Built by bunk@, Wed Aug 22 20:15:55 CEST 2001";
